.. module:: pymeasure.instruments.agilent

#######
Agilent
#######

This section contains specific documentation on the Agilent instruments that are implemented. If you are interested in an instrument not included, please consider :doc:`adding the instrument </dev/adding_instruments/index>`.

If the instrument you are looking for is not here, also check :doc:`HP<../hp/index>` for older instruments or :doc:`Keysight<../keysight/index>` for newer ones. 

.. toctree::
   :maxdepth: 2

   agilent8257D
   agilent8722ES
   agilentE4408B
   agilentE4980
   agilent34410A
   agilent34450A
   agilent4156
   agilent4294A
   agilent33220A
   agilent33500
   agilent33521A
   agilentB1500
   agilent4284A
